@@ -53,7 +53,7 @@ class testnewclass implements TestNewInterface
    }
 }
 
-class testclass implements TestRemoteInterface, TestRemoteInterface2, TestSignalInterface
+class testclass implements TestRemoteInterface, TestRemoteInterface2, TestSignalInterface, TestSignalInterface2
 {
    private DBusConnection conn;
    public testclass(DBusConnection conn)
@@ -291,6 +291,32 @@ class testclass implements TestRemoteInterface, TestRemoteInterface2, TestSignal
          || ((Map<Object,Object>) v.getValue()).size() != 1
          || !"moo".equals(((Map<Object,Object>) v.getValue()).get("cow")))
          test.fail("Didn't send variant correctly");
+   }
+	public void reg13291(byte[] as, byte[] bs)
+	{
+		if (as.length != bs.length) test.fail("didn't receive identical byte arrays");
+		for (int i = 0; i < as.length;  i++)
+			if (as[i] != bs[i]) test.fail("didn't receive identical byte arrays");
+	}
+}
+
+/**
+ * Typed signal handler for renamed signal
+ */
+class renamedsignalhandler implements DBusSigHandler<TestSignalInterface2.TestRenamedSignal>
+{
+   /** Handling a signal */
+   public void handle(TestSignalInterface2.TestRenamedSignal t)
+   {
+      if (false == test.done5) {
+         test.done5 = true;
+      } else {
+         test.fail("SignalHandler R has been run too many times");
+      }
+      System.out.println("SignalHandler R Running");
+      System.out.println("string("+t.value+") int("+t.number+")");
+      if (!"Bar".equals(t.value) || !(new UInt32(42)).equals(t.number))
+         test.fail("Incorrect TestRenamedSignal parameters");
    }
 }
 
@@ -405,6 +431,7 @@ public class test
    public static boolean done2 = false;
    public static boolean done3 = false;
    public static boolean done4 = false;
+   public static boolean done5 = false;
    public static void fail(String message)
    {
       System.out.println("Test Failed: "+message);
@@ -435,6 +462,7 @@ public class test
       try {
          /** This registers an instance of the test class as the signal handler for the TestSignal class. */
          clientconn.addSigHandler(TestSignalInterface.TestSignal.class, new signalhandler());
+         clientconn.addSigHandler(TestSignalInterface2.TestRenamedSignal.class, new renamedsignalhandler());
          String source = dbus.GetNameOwner("foo.bar.Test");
          clientconn.addSigHandler(TestSignalInterface.TestArraySignal.class, source, peer, new arraysignalhandler());
          clientconn.addSigHandler(TestSignalInterface.TestObjectSignal.class, new objectsignalhandler());
@@ -471,6 +499,7 @@ public class test
       System.out.println("Sending Signal");
       /** This creates an instance of the Test Signal, with the given object path, signal name and parameters, and broadcasts in on the Bus. */
       serverconn.sendSignal(new TestSignalInterface.TestSignal("/foo/bar/Wibble", "Bar", new UInt32(42)));
+      serverconn.sendSignal(new TestSignalInterface2.TestRenamedSignal("/foo/bar/Wibble", "Bar", new UInt32(42)));
 
       System.out.println("These things are on the bus:");
       String[] names = dbus.ListNames();
@@ -716,6 +745,13 @@ public class test
       if (4 != tri.overload()) test.fail("wrong overloaded method called");
       System.out.println("done");
 
+		System.out.print("reg13291...");
+		byte[] as = new byte[10];
+		for (int i = 0; i < 10; i++)
+			as[i] = (byte) (100-i);
+		tri.reg13291(as, as);
+		System.out.println("done");
+
       System.out.print("Testing nested lists...");
       lli = new Vector<List<Integer>>();
       li = new Vector<Integer>();
@@ -756,6 +792,7 @@ public class test
       if (!done2) fail("Signal handler 2 failed to be run");
       if (!done3) fail("Signal handler 3 failed to be run");
       if (!done4) fail("Callback handler failed to be run");
+      if (!done5) fail("Signal handler R failed to be run");
       
    } catch (Exception e) {
       e.printStackTrace();
